==> ZenTaoPMS.15.7.1.zip: zentaopms/module/message/lang/en.php <==
<?php
$lang->message->common  = 'Notification';
$lang->message->index   = 'Home';
$lang->message->setting = 'Settings';
$lang->message->browser = 'Browser Notification';

$lang->message->typeList['mail']     = 'Email';
$lang->message->typeList['message']  = 'Browser Notifications';
$lang->message->typeList['webhook']  = 'Webhook';

$lang->message->browserSetting = new stdclass();
$lang->message->browserSetting->turnon   = 'Notification';
$lang->message->browserSetting->pollTime = 'Polling Time';

$lang->message->browserSetting->pollTimePlaceholder = 'Notify the time intervals for the search by seconds.';

$lang->message->browserSetting->turnonList[1] = 'On';
$lang->message->browserSetting->turnonList[0] = 'Off';

$lang->message->label = new stdclass();
$lang->message->label->created      = 'create';
$lang->message->label->opened       = 'open';
$lang->message->label->changed      = 'change';
$lang->message->label->edited       = 'edit';
$lang->message->label->assigned     = 'assign';
$lang->message->label->closed       = 'close';
$lang->message->label->deleted      = 'delete';
$lang->message->label->undeleted    = 'restore';
$lang->message->label->commented    = 'comment';
$lang->message->label->activated    = 'activate';
$lang->message->label->resolved     = 'resolve';
$lang->message->label->reviewed     = 'review';
$lang->message->label->confirmed    = 'confirm Story';
$lang->message->label->frombug      = 'convert from Bug';
$lang->message->label->started      = 'start';
$lang->message->label->delayed      = 'delay';
$lang->message->label->suspended    = 'suspend';
$lang->message->label->finished     = 'finish';
$lang->message->label->paused       = 'pause';
$lang->message->label->canceled     = 'cancel';
$lang->message->label->restarted    = 'continue';
$lang->message->label->blocked      = 'block';
$lang->message->label->bugconfirmed = 'confirm';

==> ZenTaoPMS.16.4.zip: zentaopms/module/message/lang/en.php <==
<?php
$lang->message->common    = 'Notification';
$lang->message->index     = 'Home';
$lang->message->setting   = 'Settings';
$lang->message->browser   = 'Browser Notification';
$lang->message->blockUser = 'Block User';

$lang->message->typeList['mail']     = 'Email';
$lang->message->typeList['message']  = 'Browser Notifications';
$lang->message->typeList['webhook']  = 'Webhook';

$lang->message->browserSetting = new stdclass();
$lang->message->browserSetting->turnon   = 'Notification';
$lang->message->browserSetting->pollTime = 'Polling Time';

$lang->message->browserSetting->pollTimePlaceholder = 'Notify the time intervals for the search by seconds.';

$lang->message->browserSetting->turnonList[1] = 'On';
$lang->message->browserSetting->turnonList[0] = 'Off';

$lang->message->label = new stdclass();
$lang->message->label->created      = 'create';
$lang->message->label->opened       = 'open';
$lang->message->label->changed      = 'change';
$lang->message->label->edited       = 'edit';
$lang->message->label->assigned     = 'assign';
$lang->message->label->closed       = 'close';
$lang->message->label->deleted      = 'delete';
$lang->message->label->undeleted    = 'restore';
$lang->message->label->commented    = 'comment';
$lang->message->label->activated    = 'activate';
$lang->message->label->resolved     = 'resolve';
$lang->message->label->reviewed     = 'review';
$lang->message->label->confirmed    = 'confirm Story';
$lang->message->label->frombug      = 'convert from Bug';
$lang->message->label->started      = 'start';
$lang->message->label->delayed      = 'delay';
$lang->message->label->suspended    = 'suspend';
$lang->message->label->finished     = 'finish';
$lang->message->label->paused       = 'pause';
$lang->message->label->canceled     = 'cancel';
$lang->message->label->restarted    = 'continue';
$lang->message->label->blocked      = 'block';
$lang->message->label->bugconfirmed = 'confirm';
$lang->message->label->compilepass  = 'compile pass';
$lang->message->label->compilefail  = 'compile fail';
